#
# spec file for package libasn1c
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libasn1c
Version:        0.9.38
Release:        1.2
Summary:        Osmocon ASN.1 decoder and encoder library
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
URL:            https://gitea.osmocom.org/cellular-infrastructure/libasn1c
Source:         https://github.com/osmocom/libasn1c/archive/%version.tar.gz
BuildRequires:  libtool >= 2
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(talloc)

%description
Lev Walkins's asn1c runtime, as a shared library and with
modifications for Osmocom.

Compiles ASN.1 data structures into C source structures that can be
simply (un)marshalled from and to: BER, DER, CER, BASIC-XER, CXER,
EXTENDED-XER, PER.

%package -n libasn1c1
Summary:        Osmocon ASN.1 decoder and encoder library
Group:          System/Libraries

%description -n libasn1c1
Lev Walkins's asn1c runtime, as a shared library and with
modifications for Osmocom.

Compiles ASN.1 data structures into C source structures that can be
simply (un)marshalled from and to: BER, DER, CER, BASIC-XER, CXER,
EXTENDED-XER, PER.

%package devel
Summary:        Development files for libasn1c, Osmocom's ASN.1 decoder and encoder library
Group:          Development/Libraries/C and C++
Requires:       libasn1c1 = %version
Requires:       pkgconfig(talloc)

%description devel
Compiles ASN.1 data structures into C source structures that can be
simply (un)marshalled from and to: BER, DER, CER, BASIC-XER, CXER,
EXTENDED-XER, PER.

This subpackage contains libraries and header files for developing
applications that want to make use of libasn1c.

%prep
%autosetup -p1

%build
echo "%version" >.tarball-version
autoreconf -fi
# bugzilla.opensuse.org/795968 for rationale
%configure --disable-static --includedir="%_includedir/%name"
%make_build

%install
%make_install
find "%buildroot/%_libdir" -type f -name "*.la" -delete

%check
if ! %make_build check; then
	find . -name testsuite.log -exec cat "{}" "+"
fi

%ldconfig_scriptlets -n libasn1c1

%files -n libasn1c1
%_libdir/libasn1c.so.*

%files devel
%doc README.md
%license COPYING
%_includedir/%name/
%_libdir/pkgconfig/*.pc
%_libdir/libasn1c.so

%changelog
* Thu Feb 13 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.9.38
  * No user-visible changes
* Sun Oct 20 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.9.37
  * A readme file was added
* Wed Nov  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.9.36
  * Build fixes
* Tue May 30 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.35:
  * fix 3 indents to avoid build failure with -Werror
* Wed Aug  3 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.9.34
  * Build system change only with regard to ASan
* Sun Mar 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.9.33
  * Changes to build system only; no user-visible changes.
* Sun Sep  6 2020 Jan Engelhardt <jengelh@inai.de>
- Remove old specfile constructs.
- Move headers to distinct directory to enforce pkg-config
  correctness on library users.
* Thu Aug 15 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.9.32
  * Fix misapplication of library SO version
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.9.31
  * Build fixes
* Sun Mar 25 2018 jengelh@inai.de
- Require talloc from libasn1c-devel as its header file is used.
- Show logs on testsuite failure.
* Mon Oct  2 2017 jengelh@inai.de
- Update to new upstream snapshot 0.9.28.14
  * Relicense asn1helpers under BSD2C
* Sat Apr 29 2017 jengelh@inai.de
- Update to new upstream snapshot 0.9.28.9
  * aper fix for decoding constrained integer with lower boundary
  * fix APER encoding of integer
  * remove config.h include from asn_system.h
  * Add helper functions for uint32_t in octet strings
* Wed Dec 23 2015 jengelh@inai.de
- Initial package (version 0.9.28~20) for build.opensuse.org
